==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/SdkmessageprocessingstepsecureconfigRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Sdkmessageprocessingstepsecureconfig;
import microsoft.dynamics.crm.entity.collection.request.SdkmessageprocessingstepCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class SdkmessageprocessingstepsecureconfigRequest extends EntityRequest<Sdkmessageprocessingstepsecureconfig> {

    public SdkmessageprocessingstepsecureconfigRequest(ContextPath contextPath, Optional<Object> value) {
        super(Sdkmessageprocessingstepsecureconfig.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SdkmessageprocessingstepCollectionRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep() {
        return new SdkmessageprocessingstepCollectionRequest(
                        contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep"), Optional.empty());
    }

    public SdkmessageprocessingstepRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep(String sdkmessageprocessingstepid) {
        return new SdkmessageprocessingstepRequest(contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep").addKeys(new NameValue(sdkmessageprocessingstepid.toString())), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.46-sources.jar: microsoft/dynamics/crm/entity/request/SdkmessageprocessingstepsecureconfigRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Sdkmessageprocessingstepsecureconfig;
import microsoft.dynamics.crm.entity.collection.request.SdkmessageprocessingstepCollectionRequest;

@JsonIgnoreType
public class SdkmessageprocessingstepsecureconfigRequest extends EntityRequest<Sdkmessageprocessingstepsecureconfig> {

    public SdkmessageprocessingstepsecureconfigRequest(ContextPath contextPath, Optional<Object> value) {
        super(Sdkmessageprocessingstepsecureconfig.class, contextPath, value);
    }

    public SdkmessageprocessingstepCollectionRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep() {
        return new SdkmessageprocessingstepCollectionRequest(
                        contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep"), Optional.empty());
    }

    public SdkmessageprocessingstepRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep(String sdkmessageprocessingstepid) {
        return new SdkmessageprocessingstepRequest(contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep").addKeys(new NameValue(sdkmessageprocessingstepid.toString())), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

}
